==> fhn-manager-api-0.0.1-20160416.203031-129-sources.jar: org/gcube/resources/federation/fhnmanager/api/type/ServiceProfile.java <==
package org.gcube.resources.federation.fhnmanager.api.type;

import java.util.Date;
import java.util.Set;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement
public class ServiceProfile extends FHNResource {

	
	private String version;

	private String description;
	
	private String creationDate;
	
	private String minRam;
	
	private String minCores;
	
	private String suggestedRam;
	
	private String suggestedCores;

	private Set<ResourceReference<Software>> deployedSoftware;

	public ServiceProfile() {

	}
	
	public String getCreationDate() {
		return creationDate;
	}

	public void setCreationDate(String creationDate) {
		this.creationDate = creationDate;
	}
	
	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Set<ResourceReference<Software>> getDeployedSoftware() {
		return deployedSoftware;
	}

	@XmlElement(name = "softwarePackage")
	@XmlElementWrapper(name = "deployedSoftware")
	public void setDeployedSoftware(
			Set<ResourceReference<Software>> deployedSoftware) {
		this.deployedSoftware = deployedSoftware;
	}

	public String getMinRam() {
		return minRam;
	}

	public void setMinRam(String minRam) {
		this.minRam = minRam;
	}

	public String getMinCores() {
		return minCores;
	}

	public void setMinCores(String minCores) {
		this.minCores = minCores;
	}

	public String getSuggestedRam() {
		return suggestedRam;
	}

	public void setSuggestedRam(String suggestedRam) {
		this.suggestedRam = suggestedRam;
	}

	public String getSuggestedCores() {
		return suggestedCores;
	}

	public void setSuggestedCores(String suggestedCores) {
		this.suggestedCores = suggestedCores;
	}
}

==> fhn-manager-api-1.0.0-20160706.185819-81-sources.jar: org/gcube/resources/federation/fhnmanager/api/type/ServiceProfile.java <==
package org.gcube.resources.federation.fhnmanager.api.type;

import java.util.Date;
import java.util.Set;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement
public class ServiceProfile extends FHNResource {

	
	private String version;

	private String description;
	
	private String creationDate;
	
	private Long minRam;
	
	private int minCores;
	
	private Long suggestedRam;
	
	private int suggestedCores;

	private Set<ResourceReference<Software>> deployedSoftware;

	public ServiceProfile() {

	}
	
	public String getCreationDate() {
		return creationDate;
	}

	public void setCreationDate(String creationDate) {
		this.creationDate = creationDate;
	}
	
	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Set<ResourceReference<Software>> getDeployedSoftware() {
		return deployedSoftware;
	}

	@XmlElement(name = "softwarePackage")
	@XmlElementWrapper(name = "deployedSoftware")
	public void setDeployedSoftware(
			Set<ResourceReference<Software>> deployedSoftware) {
		this.deployedSoftware = deployedSoftware;
	}

	public Long getMinRam() {
		return minRam;
	}

	public void setMinRam(Long minRam) {
		this.minRam = minRam;
	}

	public int getMinCores() {
		return minCores;
	}

	public void setMinCores(int minCores) {
		this.minCores = minCores;
	}

	public Long getSuggestedRam() {
		return suggestedRam;
	}

	public void setSuggestedRam(Long suggestedRam) {
		this.suggestedRam = suggestedRam;
	}

	public int getSuggestedCores() {
		return suggestedCores;
	}

	public void setSuggestedCores(int suggestedCores) {
		this.suggestedCores = suggestedCores;
	}
}
